@@ -26,5 +26,8 @@ GLOBAL0(unsigned char hwaddr[6]);
 GLOBAL0(signed char no_syslog);
 GLOBAL0(signed char daemonize);
 GLOBAL(int syslog_facility, DEFAULT_FACILITY);
-
+GLOBAL0(char *vaddr_arg);
+GLOBAL0(char *xparam);
+GLOBAL(unsigned char inaddr_carp_group[4], { 224 _COMA_ 0 _COMA_ 0 _COMA_ 18 });
+GLOBAL0(sig_atomic_t received_signal);
 #endif
